package com.ti.mobpo.ui.screens

import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.lazy.grid.GridCells
import androidx.compose.foundation.lazy.grid.LazyVerticalGrid
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.unit.dp
import com.ti.mobpo.ui.viewmodels.FavouritesViewModel
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.grid.items
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Button
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.ui.Modifier

@Composable
fun FavoritesScreen(viewModel: FavouritesViewModel) {
    Favorites(viewModel)
}

@Composable
fun Favorites(favoritesViewModel: FavouritesViewModel) {
    // Function to toggle debug mode
    val toggleDebugMode: () -> Unit = {
        favoritesViewModel.toggleDebugMode()
    }

    LaunchedEffect(Unit) {
        favoritesViewModel.loadFavourites()
    }

    val favorites by favoritesViewModel.pokemonDetails.collectAsState()

    Column(
        verticalArrangement = Arrangement.Top,
        horizontalAlignment = Alignment.CenterHorizontally,
        modifier = Modifier
            .fillMaxSize()
            .padding(20.dp)
    ) {
        Spacer(modifier = Modifier.height(16.dp))

        if (favoritesViewModel.accessCheckFailed.value) {
            AlertDialog(
                onDismissRequest = {
                    favoritesViewModel.accessCheckFailed.value = false
                },
                title = {
                    Text("Access Denied")
                },
                text = {
                    Text("You do not have access to this feature.")
                },
                confirmButton = {
                    Button(
                        onClick = {
                            favoritesViewModel.accessCheckFailed.value = false
                        }
                    ) {
                        Text("OK")
                    }
                }
            )
        }

        Text(
            text = "Toggle Debug Mode",
            modifier = Modifier.clickable { toggleDebugMode() }
        )

        favorites?.let { favoritesList ->
            if (favoritesList.isNotEmpty()) {
                LazyVerticalGrid(
                    columns = GridCells.Adaptive(150.dp),
                    verticalArrangement = Arrangement.spacedBy(8.dp),
                    horizontalArrangement = Arrangement.spacedBy(8.dp)
                ) {
                    items(items = favoritesList, key = { pokemon -> pokemon.id }) { pokemon ->
                        PokemonCard(pokemon, toggleFavorite = { pokemonId ->
                            favoritesViewModel.toggleFavorite(pokemonId)
                        })
                    }
                }
            } else {
                Text("No favorites found")
            }
        }
    }
}